#[repr(u8)]pub enum BusyEvent {
Change = 1,
LoChange = 2,
}Available on crate feature
mmc only.Expand description
Device busy events
Variants
Change = 1
The drive busy state has changed
LoChange = 2
The drive busy condition has been changed by a loading/unloading operation that is not caused by command execution