#[repr(u16)]pub enum ExternalRequest {
Overrun = 1,
Play = 257,
RewindOrBack = 258,
FastForward = 259,
Pause = 260,
Stop = 262,
Ascii = 263,
VendorUnique = 61_440,
}Available on crate feature
mmc only.Expand description
Operation requested or performed via an external request to the device
Variants
Overrun = 1
The request queue has overflowed. External Request events may be lost.
Play = 257
The play button was pressed or was requested by another host.
RewindOrBack = 258
The rewind/back button was pressed or was requested by another host.
FastForward = 259
The fast forward button was pressed or was requested by another host.
Pause = 260
The pause button was pressed or was requested by another host.
Stop = 262
The stop button was pressed or was requested by another host.
Ascii = 263
A front panel button was pressed or was requested by another host.
VendorUnique = 61_440
A vendor unique request