#[repr(u8)]pub enum ExternalRequestEvent {
DriveKeyDown = 1,
DriveKeyUp = 2,
ExternalRequestNotification = 3,
}Available on crate feature
mmc only.Expand description
External request events to the device
Variants
DriveKeyDown = 1
A front, back, or remote button has been depressed
DriveKeyUp = 2
A front, back, or remote button has been released
ExternalRequestNotification = 3
The drive has received a command from another host that requires an action that may interfere with the persistent prevent owner’s operation