#[repr(u8)]pub enum MediaEvent {
EjectRequest = 1,
NewMedia = 2,
MediaRemoval = 3,
MediaChanged = 4,
BackgroundFormatCompleted = 5,
BackgroundFormatRestarted = 6,
}Available on crate feature
mmc only.Expand description
Media event
Variants
EjectRequest = 1
The drive has received a request from the user to eject the specified slot or media
NewMedia = 2
The specified slot has received new media and is ready to access it
MediaRemoval = 3
The media has been removed from the specified slot and the drive is unable to access the media without user intervention. This applies to media changers only.
MediaChanged = 4
The user has requested that the media in the specified slot be loaded. This applies to media changers only.
BackgroundFormatCompleted = 5
A DVD+RW background format has completed.
BackgroundFormatRestarted = 6
A DVD+RW background format has been automatically restarted by the drive.