MmcFeature

Enum MmcFeature 

#[non_exhaustive]
pub enum MmcFeature {
Show 61 variants ProfileList { profiles: Vec<MmcProfile>, }, Core { interface: MmcInterface, }, Morphing { async_events: bool, op_chg_events: bool, }, RemovableMedium { eject: bool, lock: bool, prevent_jumper: bool, load_mech: MmcLoadMech, }, WriteProtect, RandomReadable, MultiRead, CdRead { active: bool, c2_error: bool, cd_text: bool, dap: bool, }, DvdRead, RandomWritable, IncrementalStreamingWritable, SectorErasable, Formattable, HardwareDefectManagement, WriteOnce, RestrictedOverwrite, CdRwCavWrite, Mrw, EnhancedDefectReporting, DvdPlusRw, DvdPlusR, RigidRestrictedOverwrite, CdTrackAtOnce, CdMastering, DvdRRwWrite, DdcdRead, DdcdRWrite, DdcdRwWrite, LayerJumpRecording, LayerJumpRigidRestrictedOverwrite, StopLongOperation, CdRwMediaWriteSupport, BdRPow, DvdPlusRwDualLayer, DvdPlusRDualLayer, BdRead, BdWrite, Tsr, HdDvdRead, HdDvdWrite, HdDvdRwFragment, HybridDisc, PowerManagement, Smart, EmbeddedChanger, CdAudioExternalPlay { active: bool, scan: bool, sep_channel_mute: bool, sep_volume: bool, volume_levels: u16, }, MicrocodeUpgrade, Timeout, DvdCss { active: bool, version: u8, }, RealTimeStreaming, DriveSerialNumber { sno: String, }, MediaSerialNumber, DiscControlBlocks, DvdCprm, FirmwareInformation, Aacs, DvdCssManagedRecording, Vcps, SecurDisc, Ossc, VendorSpecific,
}
Available on crate feature mmc only.
A set of commands and behaviours that specify the capabilities of a drive and its associated medium.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ProfileList

Profile List

A list of all profiles supported by the drive

Fields

profiles: Vec<MmcProfile>


Core

Core

Mandatory behavior for all devices

Fields

interface: MmcInterface

Physical interface standard reported by MMC.

NOTE: It is possible that more than one physical interface exists between the Host and Drive, e.g., an IEEE1394 Host connecting to an ATAPI bridge to an ATAPI Drive. The Drive may not be aware of interfaces beyond the ATAPI.



Morphing

Morphing

Ability to report operational changes to the host and accept requests to prevent operational changes

Fields

async_events: bool

Supports async in addition to polling implementations of GET EVENT STATUS NOTIFICATION

op_chg_events: bool

Supports Operational Change Request/Notification Class Events



RemovableMedium

Removable Medium

Ability to remove the medium from the device

Fields

eject: bool

The drive is capable of ejecting media via START/STOP commands

lock: bool

The drive is capable of locking media

prevent_jumper: bool

The drive has a prevent jumper

load_mech: MmcLoadMech

The Loading mechanism type used by the drive



WriteProtect

Write Protect

Ability to control write protection status



RandomReadable

Random Readable

Ability to read sectors with random addressing



MultiRead

Multi-Read

The drive is able to read all CD media types; based on OSTA MultiRead



CdRead

CD Read

Ability to read CD-specific structures

Fields

active: bool

The feature is currently active

c2_error: bool

Supports C2 error pointers

cd_text: bool

Supports CD-Text (Format Code 5h of READ TOC/PMA/ATIP)

dap: bool

Supports DAP bit for the CDB in READ CD and READ CD MSF commands



DvdRead

DVD Read

Ability to read DVD-specific structures



RandomWritable

Random Writable

Write support for randomly addressed writes



IncrementalStreamingWritable

Incremental Streaming Writable

Write support for sequential recording



SectorErasable

Sector Erasable

Write support for erasable media and media that requires an erase pass before overwrite



Formattable

Formattable

Support for formatting of media



HardwareDefectManagement

Hardware Defect Management

Ability of the drive/media system to provide an apparently defect-free space



WriteOnce

Write Once

Write support for write-once media that is writable in random order



RestrictedOverwrite

Restricted Overwrite

Write support for media that shall be written from blocking boundaries only



CdRwCavWrite

CD-RW CAV Write

Ability to write high-speed CD-RW media



Mrw

MRW

Ability to recognize and read and optionally write MRW formatted media



EnhancedDefectReporting

Enhanced Defect Reporting

Ability to control RECOVERED ERROR reporting



DvdPlusRw

Ability to recognize, read and optionally write DVD+RW media



DvdPlusR

DVD+R

Ability to read DVD+R recorded media formats



RigidRestrictedOverwrite

Rigid Restricted Overwrite

Write support for media that is required to be written from Blocking boundaries with length of integral multiple of Blocking size only.



CdTrackAtOnce

CD Track At Once

Ability to write CD with Track at Once recording



CdMastering

CD Mastering

Ability to write CD with Session at Once or Raw write methods



DvdRRwWrite

DVD-R/-RW Write

Ability to write DVD specific structures



DdcdRead

DDCD Read

Ability to read user data from DDCD blocks



DdcdRWrite

DDCD-R Write

Ability to write and read DDCD-R media



DdcdRwWrite

DDCD-RW Write

Ability to write and read DDCD-RW media



LayerJumpRecording

Layer Jump Recording

Ability to record in layer jump mode



LayerJumpRigidRestrictedOverwrite

Layer Jump Rigid Restricted Overwrite

Ability to perform Layer Jump recording on Rigid Restricted Overwritable media



StopLongOperation

Stop Long Operation

Ability to stop the long immediate operation by a command



CdRwMediaWriteSupport

CD-RW Media Write Support

Ability to report CD-RW media sub-types that are supported for write



BdRPow

BD-R POW

Logical Block overwrite service on BD-R discs formatted as SRM+POW



DvdPlusRwDualLayer

DVD+RW Dual Layer

Ability to read DVD+RW Dual Layer recorded media formats



DvdPlusRDualLayer

DVD+R Dual Layer

Ability to read DVD+R Dual Layer recorded media formats



BdRead

BD Read

Ability to read control structures and user data from a BD disc



BdWrite

BD Write

Ability to write control structures and user data to certain BD discs



Tsr

Timely Safe Recording

Timely, Safe Recording permits the Host to schedule defect management



HdDvdRead

HD DVD Read

Ability to read control structures and user data from a HD DVD disc



HdDvdWrite

HD DVD Write

Ability to write control structures and user data from a HD DVD disc



HdDvdRwFragment

HD DVD-RW Fragment

HD DVD-RW fragment recording



HybridDisc

Hybrid Disc

Ability to access some hybrid discs



PowerManagement

Power Management

Host and device directed power management



Smart

SMART

Ability to perform Self Monitoring Analysis and Reporting Technology



EmbeddedChanger

Embedded Changer

Single mechanism multiple disc changer



CdAudioExternalPlay

CD Audio External Play

Ability to play audio CDs via the Logical Unit’s own analog output

Fields

active: bool

Feature is currently active

scan: bool

Supports the SCAN command

sep_channel_mute: bool

Supports independent mute of audio channels

sep_volume: bool

Supports independent volume levels for audio channels

volume_levels: u16

Number of discrete volume levels supported



MicrocodeUpgrade

Microcode Upgrade

Ability for the device to accept new microcode via the interface



Timeout

Timeout

Ability to respond to all commands within a specific time



DvdCss

DVD-CSS

Ability to perform DVD CSS/CPPM authentication and RPC

Fields

active: bool

Feature is currently active (DVD CSS/CPPM media is present)

version: u8

CSS Version



RealTimeStreaming

Real Time Streaming

Ability to read and write using host requested performance parameters



DriveSerialNumber

Drive Serial Number

The drive has a unique identifier

Fields



MediaSerialNumber

Media Serial Number

Ability to return unique Media Serial Number



DiscControlBlocks

Disc Control Blocks

Ability to read and/or write DCBs



DvdCprm

DVD CPRM

Ability to perform DVD CPRM authentication



FirmwareInformation

Firmware Information

Firmware creation date report



Aacs

AACS

Ability to decode and optionally encode AACS protected information



DvdCssManagedRecording

DVD CSS Managed Recording

Ability to perform DVD CSS managed recording



Vcps

VCPS

Ability to decode and optionally encode VCPS protected information



SecurDisc

SecurDisc

Ability to encode and decode SecurDisc protected information



Ossc

OSSC

TCG Optical Security Subsystem Class feature



VendorSpecific

Vendor Specific

Vendor-specific feature