#[repr(u8)]pub enum PowerEvent {
PwrChgSuccessful = 1,
PwrChgFail = 2,
}Available on crate feature
mmc only.Expand description
The power change event
Variants
PwrChgSuccessful = 1
The drive successfully changed to the specified power state
PwrChgFail = 2
The drive failed to enter the last requested state and is still
operating at the power state specified in the status field