SenseKey

Enum SenseKey 

#[repr(u8)]
pub enum SenseKey {
Show 15 variants NoSense = 0, RecoveredError = 1, NotReady = 2, MediumError = 3, HardwareError = 4, IllegalRequest = 5, UnitAttention = 6, DataProtect = 7, BlankCheck = 8, VendorSpecific = 9, CopyAborted = 10, AbortedCommand = 11, VolumeOverflow = 13, Miscompare = 14, Unknown(u8),
}
Available on crate feature mmc only.

Variants



NoSense = 0

No sense condition.



RecoveredError = 1

The command completed successfully, but some recovery action was taken.



NotReady = 2

The logical unit is not ready to receive the command.



MediumError = 3

The medium (disk/tape) is defective or the data is unreadable.



HardwareError = 4

A non-recoverable hardware failure occurred.



IllegalRequest = 5

An invalid field in the CDB or an unsupported command was sent.



UnitAttention = 6

The device has a condition that needs the host’s attention (e.g., medium changed).



DataProtect = 7

A command that reads or writes the medium was attempted on a protected block.



BlankCheck = 8

A write-once or sequential-access device encountered blank medium or format-defined end-of-data indication while reading or writing.



VendorSpecific = 9

Vendor specific conditions.



CopyAborted = 10

An EXTENDED COPY command was aborted due to an error condition on either the source or destination device.



AbortedCommand = 11

The device server aborted the command.



VolumeOverflow = 13

A buffered SCSI device has reached end-of-partition.



Miscompare = 14

The source data did not match the data read from the medium.



Unknown(u8)

Unknown sense key.