pub struct BusyStatus {
pub event: Option<BusyEvent>,
pub state: BusyState,
pub busy_time: Option<Duration>,
}Available on crate feature
mmc only.Expand description
Used to notify the host of commands that are executing but require an abnormally long time to complete.
Fields
event: Option<BusyEvent>Most recent device busy event on the device
state: BusyStateCurrent busy state of the device
busy_time: Option<Duration>Predicted amount of time remaining for the device to become not busy if the drive is currently busy.