pub struct CdCurrentPosition {
pub track: u8,
pub index: u8,
pub absolute_position: TimePosition,
pub relative_position: TimePosition,
}Available on crate feature
mmc only.Expand description
CD current position information.
Fields
track: u8track number
index: u8index number
absolute_position: TimePositionposition relative to the logical beginning of the media
relative_position: TimePositionposition relative to the logical beginning of the current track