pub struct ExternalRequestStatus {
pub event: Option<ExternalRequestEvent>,
pub state: ExternalRequestState,
pub request: Option<ExternalRequest>,
}Available on crate feature
mmc only.Expand description
External requests such as a remote or a button
Fields
event: Option<ExternalRequestEvent>Most recent external request event on the device
state: ExternalRequestStateDevice’s ability to respond to the host
request: Option<ExternalRequest>Operation requested or performed via an external request to the device