pub struct MediaStatus {
pub event: Option<MediaEvent>,
pub state: MediaState,
pub start_slot: u8,
pub end_slot: u8,
}Available on crate feature
mmc only.Expand description
Media related changes
Fields
event: Option<MediaEvent>Most recent media event on the device
state: MediaStateCurrent media state of the device
start_slot: u8The first slot of a multiple slot drive the media status notification applies to. Only applies to drives that support multiple slots.
end_slot: u8The last slot of a multiple slot drive the media status notification applies to. Only applies to drives that support