pub struct MmcMedium {
pub eject: bool,
pub lock: bool,
pub prevent_jumper: bool,
pub load_mech: MmcLoadMech,
}Available on crate feature
mmc only.Expand description
Removable medium info about the drive, reported by MMC.
Fields
eject: boolThe drive is capable of ejecting media via START/STOP commands
lock: boolThe drive is capable of locking media
prevent_jumper: boolThe drive has a prevent jumper
load_mech: MmcLoadMechThe Loading mechanism type used by the drive