pub struct MmcSenseData {
pub sense_key: SenseKey,
pub asc: u8,
pub ascq: u8,
pub ili: bool,
pub csi: [u8; 4],
pub fruc: u8,
pub sks: [u8; 3],
pub asb: [u8; 46],
}mmc only.Expand description
Error and status information returned by an MMC device.
Source: SPC-3 > General Concepts > Sense data > Fixed format sense data.
Fields
sense_key: SenseKeySense Key (SK) represents generic information describing an exception.
asc: u8Additional Sense Code (ASC) indicates further information related
to the exception reported by sense_key.
ascq: u8Additional Sense Code Qualifier (ASCQ) indicates detailed information related
to the additional_sense_code.
ili: boolIncorrect Length Indicator.
csi: [u8; 4]Command Specific Information indicates info that depends on the command on which the exception occured.
fruc: u8Field Replaceable Unit Code identifies a component that has failed.
sks: [u8; 3]Sense Key Specific indicates additional information about the exception.
asb: [u8; 46]Additional Sense Bytes may contain vendor specific data that further define the exception.