OperationalStatus

Struct OperationalStatus 

pub struct OperationalStatus {
    pub event: Option<OperationalEvent>,
    pub persistent_prevent: bool,
}
Available on crate feature mmc only.
Status of operational changes to the device

Fields

event: Option<OperationalEvent>

Most recent operational change event on the device

persistent_prevent: bool

Persistent prevent state is active.

Upon entering the Persistent Prevent state, the Drive shall disable any eject mechanisms, and all media after initial media spin up shall remain locked in the Drive until the Host issues an eject request, or the Persistent Prevent status is reset and the hardware eject mechanism again becomes available.