ReadCdOptions

Struct ReadCdOptions 

pub struct ReadCdOptions {
    pub expected_sector_type: Option<SectorOption>,
    pub include_sync: bool,
    pub include_header: bool,
    pub include_subheader: bool,
    pub include_user_data: bool,
    pub include_ecc: bool,
    pub include_c2_error: Option<C2Option>,
    pub include_subchannel: Option<SubchannelOption>,
}
Available on crate feature mmc only.
Disc read options.

A few options are valid only for certain sector types. Non-contiguous combinations of fields may not be feasible to read, and will result in an error (such as include_sync + include_User_data).

Fields

expected_sector_type: Option<SectorOption>

Restrict read to sector type.

include_sync: bool

Include sync fields (12 bytes per sector). Sync fields are not present in CD-DA.

include_header: bool

Include headers (4 bytes per sector). Headers are present in all sector types except CD-DA.

include_subheader: bool

Include sub-headers (8 bytes per sector). Sub-headers are present only in Mode2 formed sectors.

include_user_data: bool

Include user data. Defaults to true. Size depends on the sector type of the disc.

include_ecc: bool

Include ECC/EDC, i.e the fields that follow user data. Present only in Mode1 (288 bytes per sector) and Mode2 formed sectors (Form1: 280 bytes per sector; Form2: 4 bytes per sector).

include_c2_error: Option<C2Option>

Include “C2 error bits” (294 to 296 bytes per sector).

include_subchannel: Option<SubchannelOption>

Include sub-channel information. (16 to 96 bytes per sector).