Mmc

Struct Mmc 

pub struct Mmc { /* private fields */ }
Available on crate feature mmc only.
An interface for SCSI MMC commands.

Implementations

Source

impl Mmc

Methods related to the GET CONFIGURATION command.

pub fn features(&self) -> Result<Vec<MmcFeature>, MmcOperationError>

Get a list of MMC features supported by the device.

Returns None on error or if the device is unavailable.

Source

impl Mmc

Routines based on MMC GET EVENT STATUS NOTIFICATION.

pub fn supported_events(&self) -> Result<EventClass, MmcStatusError>

Get all the event classes supported by the device.

pub fn is_tray_open(&self) -> Result<bool, MmcStatusError>

Is the device tray open.

If the device does not have a tray, this should still return false.

pub fn operational_event_status( &self, ) -> Result<OperationalStatus, MmcStatusError>

Get operational change status from the device.

pub fn power_status(&self) -> Result<PowerStatus, MmcStatusError>

Get power management status from the device.

pub fn external_status(&self) -> Result<ExternalRequestStatus, MmcStatusError>

Get external request status from the device.

pub fn media_status(&self) -> Result<MediaStatus, MmcStatusError>

Get media status from the device.

pub fn multihost_status(&self) -> Result<MultiHostStatus, MmcStatusError>

Get multiple host event status from the device.

pub fn busy_status(&self) -> Result<BusyStatus, MmcStatusError>

Get busy status from the device.

Source

impl Mmc

Routines based on MMC INQUIRY.

pub fn hardware_identifiers( &self, ) -> Result<HardwareIdentifiers, GetHardwareIdentifiersError>

Get the hardware identifiers (Product, Vendor and Revision).

Source

impl Mmc

Routines based on MMC PREVENT ALLOW MEDIUM REMOVAL

pub fn allow_media_removal(&self) -> Result<(), MmcMediaRemovalError>

Allow media removal.

pub fn prevent_media_removal(&self) -> Result<(), MmcMediaRemovalError>

Prevent media removal.

Source

impl Mmc

Routines based on READ CD.

pub fn read_cd( &self, options: ReadCdOptions, sector: u32, count: u16, buf: &mut [u8], ) -> Result<(), MmcReadCdError>

Read disc using MMC READ CD.

The transfer size is dependent on the opted fields in the read options. See ReadCdOptions.

Source

impl Mmc

Routines based on MMC READ DISC INFORMATION.

pub fn is_disc_erasable(&self) -> Result<bool, MmcReadDiscInfoError>

Indicates that the media is of a writable kind (such as CD-RW, BD-RE, DVD+RW, etc) and the drive is capable of writing to the media.

Source

impl Mmc

Routines based on MMC READ SUB-CHANNEL.

pub fn audio_status(&self) -> Result<MmcAudioStatus, MmcAudioStatusError>

Get the status of audio play operations.

pub fn media_catalog_number(&self) -> Result<Option<String>, MmcSubchannelError>

Get the Media Catalog Number (UPC/bar code), if found.

pub fn isrc( &self, track_number: TrackNumber, ) -> Result<Option<String>, MmcSubchannelError>

Get the International Standard Recording Code (ISRC) of given track number.

pub fn cd_current_position( &self, ) -> Result<CdCurrentPosition, MmcSubchannelError>

Get the current position of the disc in time units.

Source

impl Mmc

Routines based on MMC READ TOC/PMA/ATIP.

pub fn cd_text(&self) -> Result<Vec<u8>, MmcTocError>

Get the CD-TEXT from the RW sub-channel of the media.

pub fn cd_type(&self) -> Result<CdType, MmcTocError>

Get the CD type of the media.

pub fn last_sector(&self) -> Result<u32, MmcTocError>

Get the last Logical Sector Number (LSN) of the disc

Source

impl Mmc

Routines based on MMC SET CD SPEED.

pub fn set_cd_speed( &self, rotation_mode: RotationMode, read_speed: u16, write_speed: u16, ) -> Result<(), MmcSetCdSpeedError>

Set the read and write speeds of the drive, in kilo bytes per second.

Source

impl Mmc

Routines based on MMC START STOP UNIT.

pub fn eject(&self) -> Result<(), MmcEjectError>

Eject the media, if permitted.

This might require a prior allow eject operation.

pub fn close_tray(&self) -> Result<(), MmcCloseTrayError>

Close the tray.

pub fn set_power_state( &self, state: PowerCondition, ) -> Result<(), MmcSetPowerStateError>

Set power state.

Source

impl Mmc

Routines on MMC TEST UNIT READY.

pub fn test_unit_ready(&self) -> Result<(), MmcTestUnitReadyError>

Returns Ok if the device is ready.

Source

impl Mmc

pub fn new() -> Result<Mmc, MmcNotFoundError>

Use a default device.

Errors

If an MMC capable device could not be found.

pub fn with_device(device: PathBuf) -> Result<Mmc, WithDeviceError>

Use the provided device.

Errors

If there are no devices with MMC connected, or the device could not be opened.

pub fn sense_data(&self) -> Option<MmcSenseData>

Returns the current sense data from the device.