UdfEntry

Struct UdfEntry 

pub struct UdfEntry<'a> {
    pub gid: u32,
    pub uid: u32,
    /* private fields */
}
Available on crate feature udf only.
A UDF file/directory entry.

Fields

gid: u32uid: u32

Implementations

Source

impl UdfEntry<'_>

pub fn modify_time(&self) -> Result<OffsetDateTime, UdfInvalidEntryError>

Returns the modification time.

pub fn filename(&self) -> Result<&str, UdfInvalidEntryError>

Returns the file name.

pub fn next(self) -> Option<Self>

Returns the next entry.

pub fn open_dir(&self) -> Option<Self>

Opens self and return the first entry.

pub fn is_dir(&self) -> bool

Checks if the entry is a directory.

pub fn file_length(&self) -> u64

Returns the file length.

pub fn mode(&self) -> Mode

Returns the POSIX file mode.

Returns the number of hard links of the entry.

pub fn reader(&self) -> UdfEntryReader<'_>

Returns a type that implements io::Read to allow for reading the file data of a UDF entry.